django_kubernetes_manager — Django Kubernetes Manager 0.1.0 documentation

# django_kubernetes_manager

- django_kubernetes_manager package
  - Subpackages
    - django_kubernetes_manager.migrations package
      - Submodules
      - django_kubernetes_manager.migrations.0001_initial module
      - Module contents
    - django_kubernetes_manager.models package
      - Submodules
      - django_kubernetes_manager.models.base module
      - django_kubernetes_manager.models.target_cluster module
      - Module contents
  - Submodules
  - django_kubernetes_manager.admin module
  - django_kubernetes_manager.serializers module
  - django_kubernetes_manager.urls module
  - django_kubernetes_manager.utils module
  - django_kubernetes_manager.views module
  - Module contents